==> tencentcloud-sdk-java-3.1.210-sources.jar: com/tencentcloudapi/tke/v20180525/models/CreatePrometheusTemplateRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.tke.v20180525.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class CreatePrometheusTemplateRequest extends AbstractModel{

    /**
    * 模板设置
    */
    @SerializedName("Template")
    @Expose
    private PrometheusTemplate Template;

    /**
     * Get 模板设置 
     * @return Template 模板设置
     */
    public PrometheusTemplate getTemplate() {
        return this.Template;
    }

    /**
     * Set 模板设置
     * @param Template 模板设置
     */
    public void setTemplate(PrometheusTemplate Template) {
        this.Template = Template;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamObj(map, prefix + "Template.", this.Template);

    }
}

==> tencentcloud-sdk-java-3.1.268-sources.jar: com/tencentcloudapi/tke/v20180525/models/CreatePrometheusTemplateRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.tke.v20180525.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class CreatePrometheusTemplateRequest extends AbstractModel{

    /**
    * 模板设置
    */
    @SerializedName("Template")
    @Expose
    private PrometheusTemplate Template;

    /**
     * Get 模板设置 
     * @return Template 模板设置
     */
    public PrometheusTemplate getTemplate() {
        return this.Template;
    }

    /**
     * Set 模板设置
     * @param Template 模板设置
     */
    public void setTemplate(PrometheusTemplate Template) {
        this.Template = Template;
    }

    public CreatePrometheusTemplateRequest() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public CreatePrometheusTemplateRequest(CreatePrometheusTemplateRequest source) {
        if (source.Template != null) {
            this.Template = new PrometheusTemplate(source.Template);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamObj(map, prefix + "Template.", this.Template);

    }
}
